@@ -1,5 +1,4 @@
 import os
-import sys
 
 import eyed3
 from pydub import AudioSegment
@@ -13,8 +12,8 @@ def test_trim_from_url():
 
     url = 'https://www.youtube.com/watch?v=omafc3SazWA'
     trim_from_source(url, artist='Stachu Jones', title='O kurna',
-                     no_trim=False, no_fade=False, no_normalize=False,
-                     trim_start=None, trim_end=None, gain=None)
+                     no_trim=False, no_fade=False, no_normalize=False, no_rename=False,
+                     trim_start=None, trim_end=None, gain=None, output=None)
 
     filename = 'Stachu Jones - O kurna.mp3'
     assert os.path.isfile(filename), 'output file should exist'
