@@ -1,4 +1,4 @@
-from trimmer.metadata import extract_artist_title
+from trimmer.metadata import extract_artist_title, trim_parentheses
 
 
 def test_trimming_dots_spaces():
@@ -11,3 +11,7 @@ def test_removing_brackets():
     artist, title = extract_artist_title('Pink Floyd - Welcome To The Machine (Live, Delicate Sound Of Thunder) [2019 Remix]')
     assert artist == 'Pink Floyd'
     assert title == 'Welcome To The Machine'
+
+
+def test_trim_parentheses():
+    assert trim_parentheses('Welcome To The Machine (Live at Pompeii)') == 'Welcome To The Machine'
